@@ -145,9 +145,10 @@ def roid_catcher(jd, magpsf, ndethist, sgscore1, ssdistnr, distpsnr1):
         f_relative_distance = (abs(distpsnr1) - ssdistnr) > 0.0
 
         # Not seen many times with the same objectId
-        f_ndethist = ndethist <= 2
+        f_ndethist = ndethist <= 5
+        f_nalerthist = nalerthist <= 5
 
-        mask_roid = f_distance1 & f_distance2 & f_relative_distance & f_ndethist
+        mask_roid = f_distance1 & f_distance2 & f_relative_distance & f_ndethist & f_nalerthist
         flags[mask_roid] = 3
 
     return pd.Series(flags)
