@@ -39,7 +39,6 @@ def predict_nn(
         model=None
 ) -> pd.DataFrame:
     """ Return predctions from a CBPF classifier model (cats general) using Elasticc alert data.
-
     For the default model, one has the following mapping:
 
     class_dict = {
@@ -86,11 +85,13 @@ def predict_nn(
         error in photometric redshift of host galaxy (float)
     model: spark DataFrame Column
         path to pre-trained Hierarchical Classifier model. (string)
+
     Returns:
     --------
     preds: pd.Series
         preds is an pd.Series which contains a 'cats_general_preds' column
         with probabilities for classes shown in Elasticc data challenge.
+
     Examples
     -----------
     >>> from fink_utils.spark.utils import concat_col
@@ -122,7 +123,7 @@ def predict_nn(
     >>> df = df.withColumn('cbpf_class', F.col('preds').getItem(0).astype('int'))
     >>> df = df.withColumn('cbpf_max_prob', F.col('preds').getItem(1))
     >>> df.filter(df['cbpf_class'] == 0).count()
-    1
+    0
     """
 
     filter_dict = {'u': 1, 'g': 2, 'r': 3, 'i': 4, 'z': 5, 'Y': 6}
@@ -158,16 +159,14 @@ def predict_nn(
 
     X = {
         'meta': np.array(meta),
-        'band': tf.RaggedTensor.from_row_lengths(
-            values=tf.concat(bands, axis=0),
-            row_lengths=[a.shape[0] for a in bands]
-        ),
-
-        'lc': tf.RaggedTensor.from_row_lengths(
-            values=tf.concat(lcs, axis=0),
-            row_lengths=[a.shape[0] for a in lcs]
-        )
+        'band': tf.keras.preprocessing.sequence.pad_sequences(bands,
+                                                              maxlen=243,
+                                                              dtype='int32'),
+        'lc': tf.keras.preprocessing.sequence.pad_sequences(lcs,
+                                                            maxlen=243,
+                                                            dtype='float32'),
     }
+
     for i, x in enumerate(X['meta'][:, 3]):
         if x < 0:
             X['meta'][i, 1:] = -1
@@ -177,7 +176,7 @@ def predict_nn(
     if model is None:
         # Load pre-trained model
         curdir = os.path.dirname(os.path.abspath(__file__))
-        model_path = curdir + '/data/models/cats_models/model_test_meta_ragged_alerts.h5'
+        model_path = curdir + '/data/models/cats_models/model_test_meta_alerts_tuner.h5'
     else:
         model_path = model.values[0]
 
