@@ -255,6 +255,11 @@ def snn_ia_elasticc(
     if len(midPointTai[mask]) == 0:
         return pd.Series(np.zeros(len(midPointTai), dtype=float))
 
+    # Conversion to FLUXCAL
+    fac = 10**(-(31.4 - 27.5) / 2.5)
+    psFlux = psFlux * fac
+    psFluxErr = psFluxErr * fac
+
     diaSourceId = diaSourceId.apply(lambda x: str(x))
     pdf = format_data_as_snana(
         midPointTai, psFlux, psFluxErr,
@@ -395,6 +400,11 @@ def snn_broad_elasticc(
         snn_max_prob = np.zeros(len(midPointTai), dtype=float)
         return pd.Series([[i, j] for i, j in zip(snn_class, snn_max_prob)])
 
+    # Conversion to FLUXCAL
+    fac = 10**(-(31.4 - 27.5) / 2.5)
+    psFlux = psFlux * fac
+    psFluxErr = psFluxErr * fac
+
     diaSourceId = diaSourceId.apply(lambda x: str(x))
     pdf = format_data_as_snana(
         midPointTai, psFlux, psFluxErr,
