@@ -1,4 +1,4 @@
-# Copyright 2019-2021 AstroLab Software
+# Copyright 2019-2022 AstroLab Software
 # Author: Julien Peloton
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -77,10 +77,25 @@ def spark_unit_tests(global_args: dict = None, verbose: bool = False):
     from pyspark.sql import SparkSession
     from pyspark import SparkConf
 
+    spark = SparkSession.builder.getOrCreate()
+
     conf = SparkConf()
     confdic = {
-        "spark.jars.packages": 'org.apache.spark:spark-avro_2.11:2.4.7',
-        "spark.python.daemon.module": "coverage_daemon"}
+        "spark.python.daemon.module": "coverage_daemon"
+    }
+
+    if spark.version.startswith('2'):
+        confdic.update(
+            {
+                "spark.jars.packages": 'org.apache.spark:spark-avro_2.11:{}'.format(spark.version)
+            }
+        )
+    elif spark.version.startswith('3'):
+        confdic.update(
+            {
+                "spark.jars.packages": 'org.apache.spark:spark-avro_2.12:{}'.format(spark.version)
+            }
+        )
     conf.setMaster("local[2]")
     conf.setAppName("fink_science_test")
     for k, v in confdic.items():
